[arm] SymbianOS multilibs

Paul Brook paul@codesourcery.com
Wed Aug 25 23:14:00 GMT 2004


Now that I've fixed -mfloat-abi=softfp, the SymbianOS configuration needs to 
use this for its multilib.

Patch below makes this change.  It also makes SUBTARGET_ASM_FLOAT_SPEC pass 
-mfpu=vfp and -march=armv5t to the assembler unless told otherwise.

Tested by building an arm-none-symbianelf cross.
Ok?

Paul

2005-08-15  Paul Brook  <paul@codesourcery.com>

	* symbian.h (SUBTARGET_ASM_FLOAT_SPEC): Default to -mfpu=vfp
	-march=armv5

Index: config/arm/t-symbian
===================================================================
RCS file: /var/cvsroot/gcc-cvs/gcc/gcc/config/arm/t-symbian,v
retrieving revision 1.2
diff -u -p -r1.2 t-symbian
--- config/arm/t-symbian	25 Aug 2004 19:02:56 -0000	1.2
+++ config/arm/t-symbian	25 Aug 2004 19:54:39 -0000
@@ -2,6 +2,6 @@
 # multilib for those without -- using the soft-float ABI in both
 # cases.  Symbian OS object should be compiled with interworking
 # enabled, so there are no separate thumb-mode libraries.
-MULTILIB_OPTIONS     = mfloat-abi=hard
-MULTILIB_DIRNAMES    = hard
+MULTILIB_OPTIONS     = mfloat-abi=softfp
+MULTILIB_DIRNAMES    = softfp
 



More information about the Gcc-patches mailing list
Index: config/arm/symbian.h
===================================================================
RCS file: /var/cvsroot/gcc-cvs/gcc/gcc/config/arm/symbian.h,v
retrieving revision 1.6
diff -u -p -r1.6 symbian.h
--- config/arm/symbian.h	20 Aug 2004 20:15:19 -0000	1.6
+++ config/arm/symbian.h	25 Aug 2004 22:18:10 -0000
@@ -59,9 +59,8 @@
 #undef SUBTARGET_CPU_DEFAULT
 #define SUBTARGET_CPU_DEFAULT TARGET_CPU_arm10tdmi
 
-/* The assembler should assume the VFP FPU format when the hard-float
-   ABI is in use.  */
+/* The assembler should assume VFP FPU format, and armv5t.  */
 #undef SUBTARGET_ASM_FLOAT_SPEC
 #define SUBTARGET_ASM_FLOAT_SPEC \
-  "%{!mfpu=*:%{mfloat-abi=hard:-mfpu=vfp}}"
+  "%{!mfpu=*:-mfpu=vfp} %{!mcpu=*:%{!march=*:-march=armv5t}}"
   